open Logarion
open Ocmd

let new_txt title topics_opt interactive =
	let kv = Logarion.File_store.of_kv_file () in
	let authors = Person.Set.of_string (try Logarion.Store.KV.find "Authors" kv
		with Not_found -> Sys.getenv "USER") in
	let text = { (Text.blank ()) with title; authors } in
	let text = try Text.with_str_set text "Topics" (Option.get topics_opt) with _->text in
	match File_store.with_text text with
	| Error s -> prerr_endline s
	| Ok (filepath, _note) ->
		if interactive then (Sys.command ("$EDITOR " ^ filepath) |> ignore);
		print_endline filepath

let term =
	let title = Arg.(value & pos 0 string "" & info []
		~docv:"title" ~doc:"Title for new article") in
	let topics= Arg.(value & opt (some string) None & info ["t"; "topics"]
		~docv:"comma-separated topics" ~doc:"Topics for new article") in
	let inter = Arg.(value & flag & info ["i"; "interactive"]
		~doc:"Prompts through the steps of creation") in
	Term.(const new_txt $ title $ topics $ inter), Term.info "new"
		~doc:"create a new article" ~man:[ `S "DESCRIPTION";
		`P "Create a new article, with title 'Draft' when none provided"]
